@@ -1,13 +1,13 @@
 "Image" <-
-function(x, y=NULL, pixs=1, zmax=NULL, ztrans=function(x){x},
+function(x, y=NULL, pixs=1, zmax=NULL, ztransf=function(x){x},
                   colramp=IDPcolorRamp, factors=c(FALSE,FALSE))
   ## Authors: Andreas Ruckstuhl, Rene Locher
-  ## Version: 2005-10-05
+  ## Version: 2005-10-17
 {
   if (is.matrix(x) | is.data.frame(x)) {
     if (ncol(x)>1) {
       if (is.null(y)) y <- x[,2] else
-          stop("'x' must have only 1 column when y is supplied separately")
+          stop("'x' must have only 1 column when y is supplied separately\n")
     }
     x <- x[,1]
   }
@@ -16,7 +16,7 @@ function(x, y=NULL, pixs=1, zmax=NULL, ztrans=function(x){x},
     y <- x
     x <- 1:length(x)
   }
-  if (length(y)!=length(x)) stop("Vector 'y' must have the same length as 'x'")
+  if (length(y)!=length(x)) stop("Vector 'y' must have the same length as 'x'\n")
   
   xy <- NaRV.omit(data.frame(x,y))
   factors <- factors | sapply(xy,is.factor)
@@ -39,17 +39,17 @@ function(x, y=NULL, pixs=1, zmax=NULL, ztrans=function(x){x},
      by <- seq(usr[3],usr[4], length=round(par("pin")/pixs)[2]+1)
    }
   
-  zz <- ztrans(table(cut(xy[,1],b=bx), cut(xy[,2], b=by)))
+  zz <- ztransf(table(cut(xy[,1],b=bx), cut(xy[,2], b=by)))
   zzmax <- max(zz)
 
   if(is.null(zmax)) zmax <- zzmax
   if(zmax<1||is.null(zmax)) {
-    stop("\nzmax must be >= 1 and
-          plot(x,y,...) must have been called before calling this function!")
+    stop("zmax must be >= 1 and
+          plot(x,y,...) must have been called before calling this function!\n")
   }
   
   if(zzmax>zmax)
-    stop("\nzmax too small! Densiest aereas are out of range!",call. = FALSE)
+    stop("zmax too small! Densiest aereas are out of range!",call. = FALSE)
 
   zmax <- ceiling(max(zmax,2)) ## zmax must not be smaller than 2!
 
